pymarket.statistics.maximum\_aggregated\_utility module
=======================================================

.. automodule:: pymarket.statistics.maximum_aggregated_utility
    :members:
    :undoc-members:
    :show-inheritance:
